#!/etc/opt/openit/perl -w
#
# This script adds new windows data types to the
#
#  data_generation_config
#
# file. The archtype is also made "dynamic" to allow users
# to edit which data type are generated in the portal.
#

use strict;

my $cfg = "/var/opt/openit/etc/data_generation_config";
my $old = "$cfg.old";
my $new = "$cfg.new";

# Only root can patch
if ( $< ne 0 ) {
    die "Error: Patching must be done as 'root'!\n";
}

#
# Read old config
#
open(IN, "$cfg") || die "Error: Unable to read old cfg '$cfg'!\n";
my @config = <IN>;
close(IN);

#
# Find relevant position in data file
#
my $ind = 0;
while($config[$ind]) {
    if( $config[$ind] =~ /TYPE:winapp/ ) {
	last;
    }
    $ind++;
}

#
# Verify that update is not already done
#
if( $config[$ind] =~ /dynamic/ ) {
    print STDERR "Warning: Data type update already applied!\n";
    exit 0;
}

#
# Update config
#
$config[$ind] =~ s/static/dynamic/; # Make winapp data editable in portal
$ind += 2;
splice(@config, $ind, 0,            # Add new data types
       "81:Windows Host Application Concurrent usage:appusage-windows-host-application,P1D:off\n" .
       "82:Windows Host Executable Concurrent usage:appusage-windows-host-executable,P1D:off\n" );

#
# Write to new config file (temp)
#
open(OUT, ">$new") || die "Error: Can't write new cfg '$new'!\n";
print OUT @config;
close(OUT);

#
# Rename/save old copy of file
#
if( ! rename($cfg, $old)) {
    die "Error: Unable to previous config to '$old'!\n";
}
if( ! rename($new, $cfg)) {
    die "Error: Unable to rename new config to '$cfg'!\n";
}

exit 0;
